@@ -522,7 +522,6 @@ class MfgBase2D(object):
         self.dt = self.ts[1] - self.ts[0]
         self.T = self.ts[-1]
         self.nv = nv  # diffusion paramter
-        # H(Du,m) = 0.5*|Du|^2/F1(m) - F2(m)
 
         # initail condition and terminal condition
         M0 = self.M0_func(self.xs1, self.xs2)
@@ -590,14 +589,14 @@ class MfgBase2D(object):
             dim_two_laplace = self.nv / self.dx**2 * dim_two_laplace
             return dim_two_laplace
         elif bc == "dirichlet":
-            dim_one_laplace = diags([1, -2, 1], [-1, 0, 1], format="csr")
+            dim_one_laplace = diags([1, -2, 1], [-1, 0, 1], shape=(self.Nx,self.Nx), format="csr")
             dim_two_laplace = sparse.kron(
                 dim_one_laplace, sparse.eye(self.Nx)
             ) + sparse.kron(sparse.eye(self.Nx), dim_one_laplace)
             dim_two_laplace = self.nv / self.dx**2 * dim_two_laplace
             return dim_two_laplace
         elif bc == "neumann":
-            dim_one_laplace = diags([1, -2, 1], [-1, 0, 1], format="csr")
+            dim_one_laplace = diags([1, -2, 1], [-1, 0, 1], shape=(self.Nx,self.Nx), format="csr")
             dim_one_laplace[0, 1] += 1
             dim_one_laplace[-1, -2] += 1
             dim_two_laplace = sparse.kron(
